# prometheus-virtual-metrics

## Getting Started

1. Run `docker compose up`
2. Open `http://localhost:3000` in your browser
3. Add the prometheus-virtual-metrics server as `http://prometheus-virtual-metrics:9090`
4. Go to Grafanas explore page and query for `example_metric` as a range query
